#   cryptomator-utils: Python utilities for inspecting Cryptomator drives
#   Copyright (C) 2024  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

import base64

def b64url_decode(s):
	"""
	Decode the Base64URL (optional padding) encoded string
	"""
	
	padding_len = -(len(s) % -4)
	return base64.urlsafe_b64decode(s + '=' * padding_len)

def b64url_encode(s, strip_padding=True):
	"""
	Encode the bytes with Base64URL, optionally stripping padding
	"""
	
	result = base64.urlsafe_b64encode(s)
	if strip_padding:
		result = result.rstrip(b'=')
	return result.decode('utf-8')
